## Colored Messages

delicate is a minimalist python library which gives you the possibility to print in color in the CLI.

## Install

`pip3 install delicate`

## Usage

```python
from delicate import messages

messages.log('This is my log message', 'RED')
